@@ -4,7 +4,7 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
@@ -179,6 +179,7 @@ func TestGoosGoarchCombos(t *testing.T) {
 		{"freebsd", "386", true},
 		{"freebsd", "amd64", true},
 		{"freebsd", "arm", true},
+		{"freebsd", "arm64", true},
 		{"illumos", "amd64", true},
 		{"ios", "arm64", true},
 		{"linux", "386", true},
@@ -197,9 +198,11 @@ func TestGoosGoarchCombos(t *testing.T) {
 		{"netbsd", "386", true},
 		{"netbsd", "amd64", true},
 		{"netbsd", "arm", true},
+		{"netbsd", "arm64", true},
 		{"openbsd", "386", true},
 		{"openbsd", "amd64", true},
 		{"openbsd", "arm", true},
+		{"openbsd", "arm64", true},
 		{"plan9", "386", true},
 		{"plan9", "amd64", true},
 		{"plan9", "arm", true},
