@@ -1,12 +1,11 @@
 package announce
 
 import (
-	"errors"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/hashicorp/go-multierror"
 	"github.com/stretchr/testify/require"
 )
@@ -30,7 +29,7 @@ func TestAnnounce(t *testing.T) {
 	err := Pipe{}.Run(ctx)
 	require.Error(t, err)
 	merr := &multierror.Error{}
-	require.True(t, errors.As(err, &merr), "must be a multierror")
+	require.ErrorAs(t, err, &merr, "must be a multierror")
 	require.Len(t, merr.Errors, 2)
 }
 
