@@ -96,25 +96,6 @@ func doUpload(ctx *context.Context, conf config.Blob) error {
 		return err
 	}
 
-	byTypes := []artifact.Filter{
-		artifact.ByType(artifact.UploadableArchive),
-		artifact.ByType(artifact.UploadableBinary),
-		artifact.ByType(artifact.UploadableSourceArchive),
-		artifact.ByType(artifact.Checksum),
-		artifact.ByType(artifact.Signature),
-		artifact.ByType(artifact.Certificate),
-		artifact.ByType(artifact.LinuxPackage),
-		artifact.ByType(artifact.SBOM),
-	}
-	if conf.IncludeMeta {
-		byTypes = append(byTypes, artifact.ByType(artifact.Metadata))
-	}
-
-	filter := artifact.Or(byTypes...)
-	if len(conf.IDs) > 0 {
-		filter = artifact.And(filter, artifact.ByIDs(conf.IDs...))
-	}
-
 	up := &productionUploader{
 		cacheControl:       conf.CacheControl,
 		contentDisposition: conf.ContentDisposition,
@@ -136,7 +117,7 @@ func doUpload(ctx *context.Context, conf config.Blob) error {
 	defer up.Close()
 
 	g := semerrgroup.New(ctx.Parallelism)
-	for _, artifact := range ctx.Artifacts.Filter(filter).List() {
+	for _, artifact := range artifactList(ctx, conf) {
 		g.Go(func() error {
 			// TODO: replace this with ?prefix=folder on the bucket url
 			dataFile := artifact.Path
@@ -160,6 +141,31 @@ func doUpload(ctx *context.Context, conf config.Blob) error {
 	return g.Wait()
 }
 
+func artifactList(ctx *context.Context, conf config.Blob) []*artifact.Artifact {
+	if conf.ExtraFilesOnly {
+		return nil
+	}
+	byTypes := []artifact.Filter{
+		artifact.ByType(artifact.UploadableArchive),
+		artifact.ByType(artifact.UploadableBinary),
+		artifact.ByType(artifact.UploadableSourceArchive),
+		artifact.ByType(artifact.Checksum),
+		artifact.ByType(artifact.Signature),
+		artifact.ByType(artifact.Certificate),
+		artifact.ByType(artifact.LinuxPackage),
+		artifact.ByType(artifact.SBOM),
+	}
+	if conf.IncludeMeta {
+		byTypes = append(byTypes, artifact.ByType(artifact.Metadata))
+	}
+
+	filter := artifact.Or(byTypes...)
+	if len(conf.IDs) > 0 {
+		filter = artifact.And(filter, artifact.ByIDs(conf.IDs...))
+	}
+	return ctx.Artifacts.Filter(filter).List()
+}
+
 func uploadData(ctx *context.Context, conf config.Blob, up uploader, dataFile, uploadFile, bucketURL string) error {
 	data, err := getData(ctx, conf, dataFile)
 	if err != nil {
