@@ -26,6 +26,7 @@ import (
 	"github.com/google/ko/pkg/commands/options"
 	"github.com/google/ko/pkg/publish"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/deprecate"
 	"github.com/goreleaser/goreleaser/v2/internal/ids"
 	"github.com/goreleaser/goreleaser/v2/internal/semerrgroup"
 	"github.com/goreleaser/goreleaser/v2/internal/skips"
@@ -49,8 +50,9 @@ var (
 		azureKeychain,
 	)
 
-	errNoRepository    = errors.New("ko: missing repository: please set either the repository field or a $KO_DOCKER_REPO environment variable")
-	errInvalidMainPath = errors.New("ko: invalid Main path: ko.main (or build.main if ko.main is not set) should be a relative path")
+	errNoRepository      = errors.New("ko: missing repository: please set either the repository field or a $KO_DOCKER_REPO environment variable")
+	errInvalidMainPath   = errors.New("ko: invalid Main path: ko.main (or build.main if ko.main is not set) should be a relative path")
+	errInvalidMainGoPath = errors.New("ko: invalid Main path: your path should point to a directory instead of a .go file")
 )
 
 // Pipe that build OCI compliant images with ko.
@@ -115,7 +117,11 @@ func (Pipe) Default(ctx *context.Context) error {
 			ko.Tags = []string{"latest"}
 		}
 
-		if ko.SBOM == "" {
+		switch ko.SBOM {
+		case "cyclonedx", "go.version-m":
+			deprecate.Notice(ctx, "kos.sbom")
+			ko.SBOM = "none"
+		case "":
 			ko.SBOM = "spdx"
 		}
 
@@ -214,10 +220,6 @@ func (o *buildOptions) makeBuilder(ctx *context.Context) (*build.Caching, error)
 	switch o.sbom {
 	case "spdx":
 		buildOptions = append(buildOptions, build.WithSPDX("devel"))
-	case "cyclonedx":
-		buildOptions = append(buildOptions, build.WithCycloneDX())
-	case "go.version-m":
-		buildOptions = append(buildOptions, build.WithGoVersionSBOM())
 	case "none":
 		buildOptions = append(buildOptions, build.WithDisabledSBOM())
 	default:
@@ -437,7 +439,7 @@ func validateMainPath(path string) error {
 	}
 	// paths sure can have dots in them, but if the path ends in .go, it's propably a file that one misundertood as a valid value
 	if strings.HasSuffix(path, ".go") {
-		return errInvalidMainPath
+		return errInvalidMainGoPath
 	}
 	return nil
 }
