@@ -66,6 +66,38 @@ func TestDefault(t *testing.T) {
 	}, ctx.Config.Kos[0])
 }
 
+func TestDefaultCycloneDX(t *testing.T) {
+	ctx := testctx.NewWithCfg(config.Project{
+		ProjectName: "test",
+		Env:         []string{"KO_DOCKER_REPO=" + registry},
+		Kos: []config.Ko{
+			{SBOM: "cyclonedx"},
+		},
+		Builds: []config.Build{
+			{ID: "test"},
+		},
+	})
+	require.NoError(t, Pipe{}.Default(ctx))
+	require.True(t, ctx.Deprecated)
+	require.Equal(t, "none", ctx.Config.Kos[0].SBOM)
+}
+
+func TestDefaultGoVersionM(t *testing.T) {
+	ctx := testctx.NewWithCfg(config.Project{
+		ProjectName: "test",
+		Env:         []string{"KO_DOCKER_REPO=" + registry},
+		Kos: []config.Ko{
+			{SBOM: "go.version-m"},
+		},
+		Builds: []config.Build{
+			{ID: "test"},
+		},
+	})
+	require.NoError(t, Pipe{}.Default(ctx))
+	require.True(t, ctx.Deprecated)
+	require.Equal(t, "none", ctx.Config.Kos[0].SBOM)
+}
+
 func TestDefaultNoImage(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "test",
@@ -125,6 +157,12 @@ func TestPublishPipeNoMatchingBuild(t *testing.T) {
 func TestPublishPipeSuccess(t *testing.T) {
 	testlib.StartRegistry(t, "ko_registry", registryPort)
 
+	chainguardStaticLabels := map[string]string{
+		"org.opencontainers.image.authors": "Chainguard Team https://www.chainguard.dev/",
+		"org.opencontainers.image.source":  "https://github.com/chainguard-images/images/tree/main/images/static",
+		"org.opencontainers.image.url":     "https://edu.chainguard.dev/chainguard/chainguard-images/reference/static/",
+	}
+
 	table := []struct {
 		Name               string
 		SBOM               string
@@ -138,41 +176,41 @@ func TestPublishPipeSuccess(t *testing.T) {
 	}{
 		{
 			// Must be first as others add an SBOM for the same image
-			Name: "sbom-none",
-			SBOM: "none",
+			Name:           "sbom-none",
+			SBOM:           "none",
+			ExpectedLabels: chainguardStaticLabels,
 		},
 		{
-			Name: "sbom-spdx",
-			SBOM: "spdx",
-		},
-		{
-			Name: "sbom-cyclonedx",
-			SBOM: "cyclonedx",
-		},
-		{
-			Name: "sbom-go.version-m",
-			SBOM: "go.version-m",
+			Name:           "sbom-spdx",
+			SBOM:           "spdx",
+			ExpectedLabels: chainguardStaticLabels,
 		},
 		{
 			Name:      "base-image-is-not-index",
 			BaseImage: "alpine:latest@sha256:c0d488a800e4127c334ad20d61d7bc21b4097540327217dfab52262adc02380c",
 		},
 		{
-			Name:      "multiple-platforms",
-			Platforms: []string{"linux/amd64", "linux/arm64"},
+			Name:           "multiple-platforms",
+			Platforms:      []string{"linux/amd64", "linux/arm64"},
+			ExpectedLabels: chainguardStaticLabels,
 		},
 		{
-			Name:           "labels",
-			Labels:         map[string]string{"foo": "bar", "project": "{{.ProjectName}}"},
-			ExpectedLabels: map[string]string{"foo": "bar", "project": "test"},
+			Name:   "labels",
+			Labels: map[string]string{"foo": "bar", "project": "{{.ProjectName}}"},
+			ExpectedLabels: mapsMerge(
+				map[string]string{"foo": "bar", "project": "test"},
+				chainguardStaticLabels,
+			),
 		},
 		{
-			Name:         "creation-time",
-			CreationTime: "1672531200",
+			Name:           "creation-time",
+			CreationTime:   "1672531200",
+			ExpectedLabels: chainguardStaticLabels,
 		},
 		{
 			Name:               "kodata-creation-time",
 			KoDataCreationTime: "1672531200",
+			ExpectedLabels:     chainguardStaticLabels,
 		},
 		{
 			Name: "tag-templates",
@@ -180,6 +218,7 @@ func TestPublishPipeSuccess(t *testing.T) {
 				"{{if not .Prerelease }}{{.Version}}{{ end }}",
 				"   ", // empty
 			},
+			ExpectedLabels: chainguardStaticLabels,
 		},
 		{
 			Name: "tag-template-eval-empty",
@@ -187,6 +226,7 @@ func TestPublishPipeSuccess(t *testing.T) {
 				"{{.Version}}",
 				"{{if .Prerelease }}latest{{ end }}",
 			},
+			ExpectedLabels: chainguardStaticLabels,
 		},
 	}
 
@@ -303,10 +343,6 @@ func TestPublishPipeSuccess(t *testing.T) {
 				switch table.SBOM {
 				case "spdx", "":
 					require.Equal(t, "text/spdx+json", string(mediaType))
-				case "cyclonedx":
-					require.Equal(t, "application/vnd.cyclonedx+json", string(mediaType))
-				case "go.version-m":
-					require.Equal(t, "application/vnd.go.version-m", string(mediaType))
 				default:
 					require.Fail(t, "unknown SBOM type", table.SBOM)
 				}
@@ -353,7 +389,7 @@ func TestKoValidateMainPathIssue4382(t *testing.T) {
 	require.ErrorIs(t, validateMainPath("app/"), errInvalidMainPath)
 	require.ErrorIs(t, validateMainPath("/src/"), errInvalidMainPath)
 	require.ErrorIs(t, validateMainPath("/src/app"), errInvalidMainPath)
-	require.ErrorIs(t, validateMainPath("./testdata/app/main.go"), errInvalidMainPath)
+	require.ErrorIs(t, validateMainPath("./testdata/app/main.go"), errInvalidMainGoPath)
 
 	// testing with real context
 	ctxOk := testctx.NewWithCfg(config.Project{
@@ -523,3 +559,14 @@ func TestApplyTemplate(t *testing.T) {
 		require.Error(t, err)
 	})
 }
+
+func mapsMerge(m1, m2 map[string]string) map[string]string {
+	result := map[string]string{}
+	for k, v := range m1 {
+		result[k] = v
+	}
+	for k, v := range m2 {
+		result[k] = v
+	}
+	return result
+}
