@@ -10,14 +10,14 @@ import (
 	"testing"
 
 	"github.com/google/uuid"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
 func TestStringer(t *testing.T) {
-	require.Equal(t, Pipe{}.String(), "webhook")
+	require.Equal(t, "webhook", Pipe{}.String())
 }
 
 func TestNoEndpoint(t *testing.T) {
